/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Various notifications related utility methods.
 */
Ext.define( 'QDesk.controller.ExecNotificationRuleUtils', {
  singleton: true,

  requires: [
    'QDesk.enums.MessageChannel',
    'QDesk.enums.Weekday'
  ],


  /**
   * Populates the message channel specific configuration form fields in the specified
   * EditExecNotificationRule form panel.
   * @param formPanel the EditExecNotificationRule form panel.
   * @param messageChannel a message channel (see QDesk.enums.MessageChannel).
   * @param messageChannelConfig the message channel configuration object.
   */
  populateFormMessageChannelConfig: function ( formPanel, messageChannel, messageChannelConfig )
  {
    // parse messageChannelConfig if present
    if ( messageChannelConfig )
    {
      if ( messageChannel == QDesk.enums.MessageChannel.EMAIL )
      {
        formPanel.down( '#cfgEmailSmtpHost' ).setValue( messageChannelConfig.emailSmtpHost );
        formPanel.down( '#cfgEmailSmtpPort' ).setValue( messageChannelConfig.emailSmtpPort );
        formPanel.down( '#cfgEmailSmtpUsername' ).setValue( messageChannelConfig.emailSmtpUsername );
        formPanel.down( '#cfgEmailSmtpPassword' ).setValue( messageChannelConfig.emailSmtpPassword );
        formPanel.down( '#cfgEmailFromAddr' ).setValue( messageChannelConfig.emailFromAddr );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.IM_AIM )
      {
        formPanel.down( '#cfgImAimUsername' ).setValue( messageChannelConfig.imAimUsername );
        formPanel.down( '#cfgImAimPassword' ).setValue( messageChannelConfig.imAimPassword );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.IM_GTALK )
      {
        formPanel.down( '#cfgImGTalkUsername' ).setValue( messageChannelConfig.imGTalkUsername );
        formPanel.down( '#cfgImGTalkUsernameDomain' ).setValue( messageChannelConfig.imGTalkUsernameDomain );
        formPanel.down( '#cfgImGTalkPassword' ).setValue( messageChannelConfig.imGTalkPassword );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.IM_ICQ )
      {
        formPanel.down( '#cfgImIcqUsername' ).setValue( messageChannelConfig.imIcqUsername );
        formPanel.down( '#cfgImIcqPassword' ).setValue( messageChannelConfig.imIcqPassword );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.IM_SKYPE )
      {
        formPanel.down( '#cfgImSkypeUsername' ).setValue( messageChannelConfig.imSkypeUsername );
        formPanel.down( '#cfgImSkypePassword' ).setValue( messageChannelConfig.imSkypePassword );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.IM_XMPP )
      {
        formPanel.down( '#cfgImXmppServiceName' ).setValue( messageChannelConfig.imXmppServiceName );
        formPanel.down( '#cfgImXmppHost' ).setValue( messageChannelConfig.imXmppHost );
        formPanel.down( '#cfgImXmppPort' ).setValue( messageChannelConfig.imXmppPort );
        formPanel.down( '#cfgImXmppUsername' ).setValue( messageChannelConfig.imXmppUsername );
        formPanel.down( '#cfgImXmppPassword' ).setValue( messageChannelConfig.imXmppPassword );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.IM_YAHOO )
      {
        formPanel.down( '#cfgImYahooUsername' ).setValue( messageChannelConfig.imYahooUsername );
        formPanel.down( '#cfgImYahooPassword' ).setValue( messageChannelConfig.imYahooPassword );
      }
      else if ( messageChannel == QDesk.enums.MessageChannel.WEB_SERVICE )
      {
        formPanel.down( '#cfgWebServiceEndpoint' ).setValue( messageChannelConfig.webServiceEndpoint );
        formPanel.down( '#cfgWebServiceUsername' ).setValue( messageChannelConfig.webServiceUsername );
        formPanel.down( '#cfgWebServicePassword' ).setValue( messageChannelConfig.webServicePassword );
      }
      else
      {
        Ext.Error.raise( 'Unexpected message channel value: ' + messageChannel );
      }

      // clear all validation errors in the form (could have been triggered by setting the form values...
      formPanel.getForm().clearInvalid();
    }
  },


  /**
   * Creates a QDesk.model.quartz.ExecNotificationRule model instance and populates it with
   * the specified EditExecNotificationRuleForm field values.
   * @param fieldValues a EditExecNotificationRuleForm field values.
   * @return the created QDesk.model.quartz.ExecNotificationRule model instance.
   */
  createNotificationRule: function ( fieldValues )
  {
    var me = this;

    var notificationRule = Ext.create( 'QDesk.model.quartz.ExecNotificationRule' );

    if ( !Ext.isEmpty( fieldValues.id ) )
      notificationRule.set( 'id', fieldValues.id );

    if ( !Ext.isEmpty( fieldValues.schedulerObjectName ) )
      notificationRule.set( 'schedulerObjectName', fieldValues.schedulerObjectName );

    if ( !Ext.isEmpty( fieldValues.createdAt ) )
      notificationRule.set( 'createdAt', fieldValues.createdAt );

    if ( !Ext.isEmpty( fieldValues.updatedAt ) )
      notificationRule.set( 'updatedAt', fieldValues.updatedAt );

    /* Start of Quartz specific fields */
    if ( !Ext.isEmpty( fieldValues.jobGroupName ) )
      notificationRule.set( 'jobGroupName', fieldValues.jobGroupName );

    if ( !Ext.isEmpty( fieldValues.jobName ) )
      notificationRule.set( 'jobName', fieldValues.jobName );

    if ( !Ext.isEmpty( fieldValues.triggerGroupName ) )
      notificationRule.set( 'triggerGroupName', fieldValues.triggerGroupName );

    if ( !Ext.isEmpty( fieldValues.triggerName ) )
      notificationRule.set( 'triggerName', fieldValues.triggerName );
    /* End of Quartz specific fields */

    if ( !Ext.isEmpty( fieldValues.name ) )
      notificationRule.set( 'name', fieldValues.name );

    if ( !Ext.isEmpty( fieldValues.description ) )
      notificationRule.set( 'description', fieldValues.description );

    if ( !Ext.isEmpty( fieldValues.severity ) )
      notificationRule.set( 'severity', fieldValues.severity );

    notificationRule.set( 'enabled', fieldValues.enabled );

    if ( !Ext.isEmpty( fieldValues.enabledFromTime ) )
      notificationRule.set( 'enabledFromTime', fieldValues.enabledFromTime );

    if ( !Ext.isEmpty( fieldValues.enabledToTime ) )
      notificationRule.set( 'enabledToTime', fieldValues.enabledToTime );

    notificationRule.set( 'enabledOnWeekdays', me._createEnabledOnWeekdaysArray( fieldValues ) );

    if ( !Ext.isEmpty( fieldValues.conditionType ) )
      notificationRule.set( 'conditionType', fieldValues.conditionType );

    if ( fieldValues.conditionType == QDesk.enums.ExecNotificationRuleConditionType.EXEC_STATUS )
      notificationRule.set( 'conditionExecStatus', fieldValues.conditionExecStatus );

    if ( fieldValues.conditionType == QDesk.enums.ExecNotificationRuleConditionType.MAX_DURATION )
      notificationRule.set( 'conditionMaxDuration', fieldValues.conditionMaxDuration );

    if ( fieldValues.conditionType == QDesk.enums.ExecNotificationRuleConditionType.EXPRESSION )
    {
      notificationRule.set( 'conditionExpressionLanguage', fieldValues.conditionExpressionLanguage );
      notificationRule.set( 'conditionExpression', fieldValues.conditionExpression );
    }

    if ( !Ext.isEmpty( fieldValues.messageChannelProfileId ) )
      notificationRule.set( 'messageChannelProfileId', fieldValues.messageChannelProfileId );

    if ( !Ext.isEmpty( fieldValues.messageToAddr ) )
      notificationRule.set( 'messageToAddr', fieldValues.messageToAddr );

    if ( !Ext.isEmpty( fieldValues.messageSubjectTemplate ) )
      notificationRule.set( 'messageSubjectTemplate', fieldValues.messageSubjectTemplate );

    if ( !Ext.isEmpty( fieldValues.messageBodyTemplate ) )
      notificationRule.set( 'messageBodyTemplate', fieldValues.messageBodyTemplate );

    // IM message channels do not support message attachments
    if ( QDesk.enums.MessageChannel.EMAIL == fieldValues.messageChannelProfileChannel
        || QDesk.enums.MessageChannel.WEB_SERVICE == fieldValues.messageChannelProfileChannel )
    {
      notificationRule.set( 'messageAttachLog', fieldValues.messageAttachLog );
      notificationRule.set( 'messageAttachError', fieldValues.messageAttachError );
      notificationRule.set( 'messageAttachResult', fieldValues.messageAttachResult );
      notificationRule.set( 'messageAttachUserData', fieldValues.messageAttachUserData );
    }
    else
    {
      notificationRule.set( 'messageAttachLog', false );
      notificationRule.set( 'messageAttachError', false );
      notificationRule.set( 'messageAttachResult', false );
      notificationRule.set( 'messageAttachUserData', false );
    }

    return notificationRule;
  },


  /**
   * Returns the message channel configuration object created from the specified
   * form field values.
   * @param fieldValues form field values.
   * @return the message channel configuration object.
   */
  _createEnabledOnWeekdaysArray: function ( fieldValues )
  {
    var enabledOnWeekdays = [];

    if ( fieldValues.enabledOnMonday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.MONDAY );

    if ( fieldValues.enabledOnTuesday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.TUESDAY );

    if ( fieldValues.enabledOnWednesday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.WEDNESDAY );

    if ( fieldValues.enabledOnThursday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.THURSDAY );

    if ( fieldValues.enabledOnFriday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.FRIDAY );

    if ( fieldValues.enabledOnSaturday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.SATURDAY );

    if ( fieldValues.enabledOnSunday )
      enabledOnWeekdays.push( QDesk.enums.Weekday.SUNDAY );

    return enabledOnWeekdays;
  }
} );
