/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Tests a scheduler connection.
 */
Ext.define( 'QDesk.controller.command.connection.TestSchedulerConnection', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.Msg',
    'QDesk.enums.ProductEdition',
    'QDesk.enums.ServerErrorType',
    'QDesk.util.UxUtils',
    'QDesk.util.license.LicensedProduct'
  ],

  /*
   * Required config parameter with the AddConnection, or EditConnection window
   * that initiated the discovery.
   */
  window : undefined,

  /**
   * Required config parameter with the scheduler type.
   * See QDesk.enums.scheduler.SchedulerType.
   */
  schedulerType : undefined,

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.window )
      Ext.Error.raise( 'Required config parameter missing: window' );

    if ( !config.schedulerType )
      Ext.Error.raise( 'Required config parameter missing: schedulerType' );

    me.callParent( [config] );
  },


  execute : function ()
  {
    var me = this;

    var formPanel = me.window.down( '#form' );

    var useServiceParams = formPanel.down( '#serviceParamsRadio' ).getValue();
    var useServiceUrl = formPanel.down( '#serviceUrlRadio' ).getValue();

    var fieldValues = formPanel.getForm().getFieldValues();

    var connection = Ext.create( 'QDesk.model.Connection',
        {
          name : fieldValues.name,
          remoteJmxService : {
            protocol : useServiceParams ? fieldValues.protocol : null,
            host : useServiceParams ? fieldValues.host : null,
            port : useServiceParams ? fieldValues.port : null,
            serviceUrl : useServiceUrl ? fieldValues.serviceUrl : null,
            authentication : {
              username : fieldValues.username ? fieldValues.username : null,
              password : fieldValues.password ? fieldValues.password : null
            }
          },
          schedulerType : me.schedulerType,
          schedulerObjectName : fieldValues.schedulerObjectName
        }
    );

    if ( fieldValues.username == '' && fieldValues.password == '' )
      connection.get( 'remoteJmxService' ).authentication = null;

    QDesk.util.UxUtils.maskEl( me.window.getEl(),
        QDesk.Msg.get( 'QDesk.controller.command.connection.TestSchedulerConnection.maskMsg' ) );

    Ext.Ajax.request( {
      url : QDesk.util.constant.ActionUrl.commonSchedulerActionTest,
      params : {
        connection : Ext.encode( connection.data )

      },
      callback : function ( opts, success, resp )
      {
        QDesk.util.UxUtils.unmaskEl( me.window.getEl() );

        if ( success )
        {
          var json = Ext.decode( resp.responseText );
          if ( json.success )
          {
            if ( json.scheduler )
            {
              // Lite edition
              if ( QDesk.util.license.LicensedProduct.productEdition == QDesk.enums.ProductEdition.LITE )
              {
                QDesk.util.UxUtils.showInfoDialog(
                    QDesk.Msg.get( 'QDesk.controller.command.connection.TestSchedulerConnection.successMsg' ) );
              }
              else
              {
                // Standard and Enterprise editions
                if ( json.jvmAgentAvailable )
                {
                  QDesk.util.UxUtils.showInfoDialog(
                      QDesk.Msg.get( 'QDesk.controller.command.connection.TestSchedulerConnection.successJvmAgentAvailableMsg' ) );
                }
                else
                {
                  QDesk.util.UxUtils.showWarningDialog(
                      QDesk.Msg.get( 'QDesk.controller.command.connection.TestSchedulerConnection.successJvmAgentNotAvailableMsg' ) );
                }
              }
            }
            else
            {
              QDesk.util.UxUtils.showWarningDialog(
                  QDesk.Msg.get( 'QDesk.controller.command.connection.TestSchedulerConnection.noSchedulerFoundMsg' ) );
            }
          }
          else
          {
            // application errors are shown in a warning dialogs
            if ( json.errorType && json.errorType == QDesk.enums.ServerErrorType.APPLICATION )
            {
              QDesk.util.UxUtils.showWarningDialog( json.errors[0].msg );
            }
            else
            {
              QDesk.util.UxUtils.showJsonResponseErrors( json );
            }
          }
        }
        else
        {
          QDesk.util.UxUtils.showErrorDialog(
              QDesk.Msg.get( 'QDesk.controller.command.connection.TestSchedulerConnection.errorMsg' ) );
        }
      }
    } )
  }
} );
