/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Refreshes the Execution History view in the scheduler view panel's Jobs tab.
 */
Ext.define( 'QDesk.controller.command.scheduler.quartz.jobs.RefreshJobHistoryView', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.controller.QuartzControllerUtils',
    'QDesk.controller.command.connection.ConnectionUtils',
    'QDesk.util.constant.ActionUrl',
    'QDesk.util.license.LicensedProductFeatures'
  ],

  /*
   * Required connection ID config parameter.
   */
  connectionId : undefined,

  /**
   * A required flag indicating whether the view should be populated with data to reflect the currently selected job.
   */
  populate : undefined,


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.connectionId )
      Ext.Error.raise( 'Required config parameter missing: connectionId' );

    if ( config.populate == null )
      Ext.Error.raise( 'Required config parameter missing: populate' );

    me.callParent( [config] );
  },


  execute : function ()
  {
    var me = this;

    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    if ( licensedFeatures.JobExecutionHistory &&
        QDesk.controller.command.connection.ConnectionUtils.isJvmAgentAvailable( me.connectionId ) )
    {
      var jobsTab = QDesk.controller.QuartzControllerUtils.getJobsTab( me.connectionId );
      var jobsGrid = jobsTab.down( '#jobsGrid' );

      var selectedJobDetails = jobsGrid.getSelectionModel().getSelection();

      var execHistoryGrid = jobsTab.down( '#execHistoryGrid' );

      var execHistoryGridStore = execHistoryGrid.getStore();

      var maxFetchDate = execHistoryGrid.down( '#maxFetchDateSelect' ).getValue();
      var maxFetchSize = execHistoryGrid.down( '#maxFetchSizeSelect' ).getValue();

      var reloadStores = true;

      if ( me.populate )
      {
        if ( Ext.isEmpty( selectedJobDetails ) )
        {
          execHistoryGridStore.getProxy().url = QDesk.util.constant.ActionUrl.emptyStoreAction;
          execHistoryGridStore.getProxy().extraParams = {};
        }
        else
        {
          var jobDetail = selectedJobDetails[0];

          execHistoryGridStore.getProxy().url =
              QDesk.util.constant.ActionUrl.quartz.execHistoryActionListForJob;

          execHistoryGridStore.getProxy().extraParams = {
            connectionId : me.connectionId,
            jobGroupName : jobDetail.get( 'group' ).name,
            jobName : jobDetail.get( 'name' ),
            maxFetchDate : maxFetchDate,
            maxFetchSize : maxFetchSize == -1 ? null : maxFetchSize  // -1 == unlimited
          };
        }
      }
      else
      {
        if ( execHistoryGridStore.getProxy().url == QDesk.util.constant.ActionUrl.emptyStoreAction )
          reloadStores = false;

        execHistoryGridStore.getProxy().url = QDesk.util.constant.ActionUrl.emptyStoreAction;
        execHistoryGridStore.getProxy().extraParams = {};
      }

      // optimization to avoid repeated reloads of empty stores
      if ( reloadStores )
      {
        execHistoryGridStore.loadPage( 1, {
          scope : me,
          callback : function ( records, operation, success )
          {
            if ( success )
            {
              // invoke the success callback handler
              if ( me.success && Ext.isFunction( me.success ) )
              {
                me.success.apply( me );
              }
            }
            else
            {
              // invoke the failure callback handler
              if ( me.failure && Ext.isFunction( me.failure ) )
              {
                me.failure.apply( me );
              }
            }
          }
        } );
      }
    }
  }
} )
;
