/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Refreshes the scheduler Notification Rules grid in the scheduler Notifications panel.
 */
Ext.define( 'QDesk.controller.command.scheduler.quartz.notif.exec.RefreshSchedulerExecNotificationRulesGrid', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.Msg',
    'QDesk.controller.QuartzControllerUtils',
    'QDesk.controller.command.connection.ConnectionUtils',
    'QDesk.util.constant.ActionUrl',
    'QDesk.util.license.LicensedProductFeatures'
  ],

  /*
   * Required connection ID config parameter.
   */
  connectionId : undefined,


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.connectionId )
      Ext.Error.raise( 'Required config parameter missing: connectionId' );

    me.callParent( [config] );
  },


  execute : function ()
  {
    var me = this;

    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    if ( licensedFeatures.SchedulerExecutionNotifications &&
        QDesk.controller.command.connection.ConnectionUtils.isJvmAgentAvailable( me.connectionId ) )
    {
      var schedulerNotificationsTab = QDesk.controller.QuartzControllerUtils.getSchedulerNotificationsTab( me.connectionId );
      var notificationRulesGrid = schedulerNotificationsTab.down( '#execNotificationRulesGrid' );

      var notificationRulesGridStore = notificationRulesGrid.getStore();

      var reloadStores = true;

      notificationRulesGridStore.getProxy().url =
          QDesk.util.constant.ActionUrl.quartz.execNotificationRuleActionListForScheduler;

      notificationRulesGridStore.getProxy().extraParams = {
        connectionId : me.connectionId
      };

      // optimization to avoid repeated reloads of empty stores
      if ( reloadStores )
        notificationRulesGridStore.loadPage( 1, {
          scope : me,
          callback : function ( records, operation, success )
          {
            if ( success )
            {
              // invoke the success callback handler
              if ( me.success && Ext.isFunction( me.success ) )
              {
                me.success.apply( me );
              }
            }
            else
            {
              // invoke the failure callback handler
              if ( me.failure && Ext.isFunction( me.failure ) )
              {
                me.failure.apply( me );
              }
            }
          }
        } );
    }
  }
} );
