/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * The Quartz scheduler trigger data model based on the
 * {@link com.quartzdesk.domain.model.scheduler.quartz.Trigger} class.
 */
Ext.define( 'QDesk.model.quartz.Trigger', {
  extend : 'Ext.data.Model',

  requires : [
    'QDesk.util.constant.DateFormat'
  ],

  fields : [
    /*
     * Start of common trigger attributes.
     */
    { name : 'name', type : 'string' },
    { name : 'group', type : 'QDesk.model.quartz.TriggerGroup' },

    /* com.quartzdesk.domain.model.scheduler.quartz.TriggerState */
    { name : 'state', type : 'string' },

    { name : 'jobName', type : 'string' },
    { name : 'jobGroup', type : 'QDesk.model.quartz.JobGroup' },

    { name : 'calendarName', type : 'string' },

    { name : 'description', type : 'string' },

    { name : 'priority', type : 'int', useNull : true },

    { name : 'misfireInstruction', type : 'int', useNull : true },

    /* All dates are expected in ISO 8601 format (dateFormat: QDesk.util.constant.DateFormat.timestampParseFormat) */
    { name : 'startTime', type : 'date', dateFormat : QDesk.util.constant.DateFormat.timestampParseFormat },
    { name : 'endTime', type : 'date', dateFormat : QDesk.util.constant.DateFormat.timestampParseFormat},

    { name : 'previousFireTime', type : 'date', dateFormat : QDesk.util.constant.DateFormat.timestampParseFormat },
    { name : 'nextFireTime', type : 'date', dateFormat : QDesk.util.constant.DateFormat.timestampParseFormat },
    { name : 'finalFireTime', type : 'date', dateFormat : QDesk.util.constant.DateFormat.timestampParseFormat },

    { name : 'jobDataMap', type : 'auto' },
    { name : 'effectiveJobDataMap', type : 'auto' },

    /*
     * Quartz 1.x.
     */
    { name : 'volatility', type : 'boolean' },

    /* End of common trigger attributes */

    /* CronTrigger specific fields */
    { name : 'cronExpression', type : 'string' },
    { name : 'timeZone', type : 'string' },

    /* SimpleTrigger specific fields */
    { name : 'repeatCount', type : 'int', useNull : true },
    { name : 'repeatInterval', type : 'int', useNull : true },
    { name : 'timesTriggered', type : 'int', useNull : true },

    /*
     * QuartzDesk trigger monitoring URL.
     * Read-only property.
     */
    { name : 'monitoringUrl', type : 'string' }
  ]} );
