/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Base class for a scheduler tab sub-tabs. This class provides access to the
 * sub-tab initialization flag and scheduler description object in the parent
 * tab.
 */
Ext.define( 'QDesk.view.base.scheduler.BaseSchedulerSubTab', {
  extend : 'Ext.panel.Panel',

  requires : [],

  bodyCls : 'baseSchedulerSubTabBody',

  closable : false,

  autoScroll : true,

  /**
   * Returns the value of the QDesk boolean flag indicating whether tab has been initialized.
   * @return the QDesk initialization flag.
   */
  getInitialized : function ()
  {
    return this.qdesk.initialized;
  },


  /**
   * Sets the value of the QDesk boolean flag indicating whether tab has been initialized.
   * @param initialized the QDesk initialization flag.
   */
  setInitialized : function ( initialized )
  {
    this.qdesk.initialized = initialized;
  },


  /**
   * Returns the connection ID this tab has been created for.
   * @return the connection ID.
   */
  getConnectionId : function ()
  {
    var me = this;
    var schedulerTab = me.up( 'panel' );
    // assert schedulerTab != null
    return schedulerTab.getConnectionId();
  },


  /**
   * Returns true if the QuartzDesk JVM Agent was available when opening the scheduler tab, false otherwise.
   * @return true if the QuartzDesk JVM Agent was available when opening the scheduler tab, false otherwise.
   */
  isJvmAgentAvailable : function ()
  {
    var me = this;
    var schedulerTab = me.up( 'panel' );
    // assert schedulerTab != null
    return schedulerTab.isJvmAgentAvailable();
  },


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      qdesk : {
        // tab initialization flag
        initialized : false
      }
    } );

    me.callParent( [config] );
  }
} );
