/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Base class for all scheduler tabs.
 */
Ext.define( 'QDesk.view.base.scheduler.BaseSchedulerTab', {
  extend : 'Ext.tab.Panel',

  closable : 'true',

  qdesk : {
    /*
     * Required config parameter with the ID of the scheduler connection.
     */
    connectionId : undefined,

    /*
     * Required config parameter with QuartzDesk JVm Agent information for the scheduler
     * connection obtained at the time when the scheduler tab has been opened.
     */
    jvmAgentInfo : undefined
  },


  /**
   * Returns the connection ID this tab has been created for.
   * @return the connection ID.
   */
  getConnectionId : function ()
  {
    return this.qdesk.connectionId;
  },


  /**
   * Returns true if the QuartzDesk JVM Agent was available when this tab was opened, false otherwise.
   * @return true if the QuartzDesk JVM Agent was available when this tab was opened, false otherwise.
   */
  isJvmAgentAvailable : function ()
  {
    return this.getJvmAgentInfo().available;
  },


  /**
   * Returns the info on the QuartzDesk JVM Agent for the scheduler this tab has been opened for.
   * @return the info object with the following structure:
   * <pre>
   * {
   *   "available" : true,
   *   "nameAndVersion" : "QuartzDesk JVM Agent v1.3.0-SNAPSHOT",
   *   "version" : {
   *     "major" : 1,
   *     "minor" : 3,
   *     "maintenance" : 0,
   *     "qualifier" : "SNAPSHOT"
   *   },
   *   "displayVersion" : "1.3.0-SNAPSHOT"
   * }
   * </pre>
   */
  getJvmAgentInfo : function ()
  {
    return this.qdesk.jvmAgentInfo;
  },


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.connectionId )
      Ext.Error.raise( 'Required config parameter missing: qdesk.connectionId' );

    if ( config.qdesk.jvmAgentInfo == null )
      Ext.Error.raise( 'Required config parameter missing: qdesk.jvmAgentInfo' );

    me.callParent( [config] );
  }
} );
