/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.main.scheduler.quartz.jobs.triggers.JobTriggersGrid', {
  extend : 'QDesk.view.widget.ConfigurableGrid',

  requires : [
    'QDesk.Config',
    'QDesk.Msg',
    'QDesk.store.quartz.JobTriggerStore',
    'QDesk.store.quartz.TriggerGroupStore',

    'QDesk.util.constant.ActionUrl',
    'QDesk.util.constant.DateFormat',

    'QDesk.util.license.LicensedProductFeatures',

    'Ext.ux.CheckColumn',
    'Ext.ux.RowExpander'
  ],

  alias : 'widget.QuartzJobTriggersGrid',

  cls : 'quartzJobTriggersGrid',

  autoScroll : true,

  //border : false,

  tbar : [
    {
      xtype : 'button',
      itemId : 'refreshButton',
      scale : 'small',
      iconCls : 'refresh',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipRefreshButton' ),
      disabled : true
    },
    '-',
    {
      xtype : 'button',
      itemId : 'resumeTriggerButton',
      scale : 'small',
      iconCls : 'resumeTrigger',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipResumeTriggerButton' ),
      disabled : true
    },
    {
      xtype : 'button',
      itemId : 'pauseTriggerButton',
      scale : 'small',
      iconCls : 'pauseTrigger',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipPauseTriggerButton' ),
      disabled : true
    },
    '-',
    {
      xtype : 'button',
      itemId : 'deleteTriggerButton',
      scale : 'small',
      iconCls : 'deleteTrigger',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipDeleteTriggerButton' ),
      disabled : true
    },
    '-',
    {
      xtype : 'xcombo',
      itemId : 'filterByTriggerGroupCombo',
      //fieldLabel : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.filterByJobGroupComboLabel' ),
      //labelWidth : 'auto',
      //labelAlign : 'right',
      displayField : 'name',
      valueField : 'name',
      queryMode : 'local',
      editable : false,
      emptyText : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.emptyTextFilterByTriggerGroupCombo' ),
      //store: store,   // store set in initComponent
      disabled : true
    },
    {
      xtype : 'button',
      itemId : 'resumeTriggerGroupButton',
      scale : 'small',
      iconCls : 'resumeTriggerGroup',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipResumeTriggerGroupButton' ),
      disabled : true
    },
    {
      xtype : 'button',
      itemId : 'pauseTriggerGroupButton',
      scale : 'small',
      iconCls : 'pauseTriggerGroup',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipPauseTriggerGroupButton' ),
      disabled : true
    },
    {
      xtype : 'tbfill'
    },
    {
      xtype : 'button',
      itemId : 'saveGridConfigButton',
      scale : 'small',
      iconCls : 'saveGridConfig',
      tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipSaveGridConfigButton' ),
      disabled : false
    }
  ],


  columns : [
    {
      itemId : 'nameColumn',
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textNameColumn' ),
      dataIndex : 'name',
      sortable : true,
      groupable : false,
      flex : 1
    },
    {
      xtype : 'templatecolumn',
      itemId : 'groupNameColumn',
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textGroupNameColumn' ),
      dataIndex : 'group.name',
      tpl : '{group.name}',
      sortable : true,
      groupable : true,
      flex : 1
    },
    {
      itemId : 'stateColumn',
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textStateColumn' ),
      dataIndex : 'state',
      sortable : true,
      groupable : true,
      flex : 0.5
    },
    {
      xtype : 'actioncolumn',
      itemId : 'jobDataMapColumn',
      align : 'center',
      menuText : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textJobDataMapColumn' ),
      header : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textJobDataMapColumn' ),
      sortable : false,
      groupable : false,
      width : 100,
      items : [
        {
          icon : 'images/icon/job-data-map-16x16.png',
          iconCls : 'clickable',
          tooltip : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipJobDataMapColumn' ),
          handler : function ( grid, rowIndex, colIndex )
          {
            var triggerRecord = grid.getStore().getAt( rowIndex );

            var jobDataMap = triggerRecord.get( 'jobDataMap' );
            var effectiveJobDataMap = triggerRecord.get( 'effectiveJobDataMap' );
            this.fireEvent( 'requestViewJobDataMap', jobDataMap, effectiveJobDataMap );
          }
        }
      ]
    },
    {
      xtype : 'datecolumn',
      itemId : 'startTimeColumn',
      format : QDesk.util.constant.DateFormat.timestampRenderFormat,
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textStartTimeColumn' ),
      dataIndex : 'startTime',
      sortable : true,
      groupable : true,
      flex : 1
    },
    {
      xtype : 'datecolumn',
      itemId : 'endTimeColumn',
      format : QDesk.util.constant.DateFormat.timestampRenderFormat,
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textEndTimeColumn' ),
      dataIndex : 'endTime',
      sortable : true,
      groupable : true,
      flex : 1
    },
    {
      xtype : 'datecolumn',
      itemId : 'previousFireTimeColumn',
      format : QDesk.util.constant.DateFormat.timestampRenderFormat,
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textPreviousFireTimeColumn' ),
      dataIndex : 'previousFireTime',
      sortable : true,
      groupable : true,
      flex : 1
    },
    {
      xtype : 'datecolumn',
      itemId : 'nextFireTimeColumn',
      format : QDesk.util.constant.DateFormat.timestampRenderFormat,
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textNextFireTimeColumn' ),
      dataIndex : 'nextFireTime',
      sortable : true,
      groupable : true,
      flex : 1
    },
    {
      xtype : 'datecolumn',
      itemId : 'finalFireTimeColumn',
      format : QDesk.util.constant.DateFormat.timestampRenderFormat,
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textFinalFireTimeColumn' ),
      dataIndex : 'finalFireTime',
      sortable : true,
      groupable : true,
      flex : 1
    },
    {
      itemId : 'calendarNameColumn',
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textCalendarNameColumn' ),
      dataIndex : 'calendarName',
      sortable : false,
      groupable : false,
      flex : 1
    },
    {
      xtype : 'numbercolumn',
      itemId : 'priorityColumn',
      format : '0',
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textPriorityColumn' ),
      dataIndex : 'priority',
      sortable : false,
      groupable : false,
      flex : 0.5
    },
    {
      xtype : 'numbercolumn',
      itemId : 'misfireInstructionColumn',
      format : '0',
      text : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.textMisfireInstructionColumn' ),
      dataIndex : 'misfireInstruction',
      sortable : false,
      groupable : false,
      flex : 1
    }
  ],


  plugins : [
    {
      ptype : 'rowexpander',
      rowBodyTpl : [
        '<p>' +
            '<b>{[QDesk.Msg.get( \"QDesk.description\" )]}:</b> ' +
            '<tpl if="description">{[Ext.htmlEncode(values.description)]}</tpl>' +
            '<tpl if="!description">{[Ext.htmlEncode(QDesk.Msg.get( \"QDesk.notAvailable\" ))]}</tpl>' +
            '</p>' +

            '<p style="white-space: nowrap">' +
            '<b>{[QDesk.Msg.get( \"QDesk.monitoringUrl\" )]}:</b> ' +
            '{[this.getMonitoringLink( values.monitoringUrl )]}' +
            '</p>',
        {
          getMonitoringLink : function ( monitoringUrl )
          {
            var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;
            if ( licensedFeatures.TriggerMonitoring )
            {
              var tooltip = Ext.htmlEncode( QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipMonitoringUrl' ) );
              return '<a href="' + monitoringUrl +
                  '" class="newWindow" target="_blank" data-qtip="' + tooltip + '">' + monitoringUrl + '</a>';
            }
            else
            {
              var tooltip = Ext.htmlEncode( QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.jobs.JobTriggersGrid.tooltipMonitoringUrlNotLicensed' ) );
              return '<a href="' + monitoringUrl +
                  '" class="newWindow notLicensed" onclick="javascript:return false" target="_blank" data-qtip="' +
                  tooltip + '">' + monitoringUrl + '</a>';
            }
          }
        }
      ]
    }
  ],


  initComponent : function ()
  {
    var me = this;

    me.callParent();

    var jobTriggerGroupStore = Ext.create( 'QDesk.store.quartz.JobTriggerGroupStore' );
    jobTriggerGroupStore.getProxy().url = QDesk.util.constant.ActionUrl.emptyStoreAction;

    me.down( '#filterByTriggerGroupCombo' ).store = jobTriggerGroupStore;
  },


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.connectionId )
      Ext.Error.raise( 'Required config parameter missing: qdesk.connectionId' );

    var jobTriggerStore = Ext.create( 'QDesk.store.quartz.JobTriggerStore' );

    Ext.apply( config, {
      store : jobTriggerStore,

      qdesk : {
        gridId : 'quartz.jobTriggersGrid',
        connectionId : config.qdesk.connectionId
      }
    } );

    me.callParent( [config] );
  }
} );
