/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.main.scheduler.quartz.stats.ExecTimeChart', {
  extend : 'Ext.chart.Chart',

  requires : [
    'QDesk.Msg',
    'QDesk.enums.ExecStatus',
    'QDesk.enums.scheduler.quartz.SchedulerStatisticsType',
    'QDesk.store.quartz.stats.ExecStatDataStore',
    'QDesk.util.EnumUtils',

    'Ext.chart.theme.QuartzExecTimeChartTheme'
  ],

  style : 'background:#fff',

  animate : true,

  shadow : true,

  theme : 'QuartzExecTimeChartTheme',

  legend : {
    boxStroke : '#444444',
    labelColor : '#444444',
    position : 'right'
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      store : Ext.create( 'QDesk.store.quartz.stats.ExecStatDataStore' ),

      axes : [
        {
          type : 'Numeric',
          minimum : 0,
          position : 'left',
          fields : ['avgTimeSuccess', 'avgTimeError'],
          title : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.ExecTimeChart.labelValueAxis' ),
          minorTickSteps : 1,
          grid : {
            odd : {
              opacity : 1,
              fill : '#ddd',
              stroke : '#bbb',
              'stroke-width' : 0.5
            }
          }
        },

        {
          type : 'Category',
          position : 'bottom',
          fields : ['periodChartDisplayName'],
          title : QDesk.Msg.get( 'QDesk.charts.labelPeriodAxis.' + config.qdesk.periodLength )
        }
      ],

      series : [
        {
          type : 'column',
          title : [
            QDesk.util.EnumUtils.getExecStatusName( QDesk.enums.ExecStatus.SUCCESS ),
            QDesk.util.EnumUtils.getExecStatusName( QDesk.enums.ExecStatus.ERROR )
          ],
          axis : 'left',
          smooth : true,
          xField : 'periodChartDisplayName',
          yField : ['avgTimeSuccess', 'avgTimeError'],

          tips : {
            dismissDelay : 0,
            trackMouse : true,
            renderer : function ( storeItem, item )
            {
              if ( item.yField == 'avgTimeSuccess' )
              {
                var html = QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.ExecTimeChart.tooltipSuccessBar',
                    QDesk.util.FormatUtils.parseAndFormatTimestamp( storeItem.get( 'period' ).from ),
                    QDesk.util.FormatUtils.parseAndFormatTimestamp( storeItem.get( 'period' ).to ),
                    Ext.util.Format.number( storeItem.get( 'countSuccess' ), '0,000' ),
                    Ext.util.Format.number( storeItem.get( 'timeSuccess' ), '0,000' ),
                    Ext.util.Format.number( storeItem.get( 'avgTimeSuccess' ), '0,000.00' ),
                    Ext.util.Format.number( storeItem.get( 'countSuccessError' ), '0,000' ),
                    Ext.util.Format.number( storeItem.get( 'avgTimeSuccessError' ), '0,000.00' ) );

                this.update( html );
              }
              else if ( item.yField == 'avgTimeError' )
              {
                var html = QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.ExecTimeChart.tooltipErrorBar',
                    QDesk.util.FormatUtils.parseAndFormatTimestamp( storeItem.get( 'period' ).from ),
                    QDesk.util.FormatUtils.parseAndFormatTimestamp( storeItem.get( 'period' ).to ),
                    Ext.util.Format.number( storeItem.get( 'countError' ), '0,000' ),
                    Ext.util.Format.number( storeItem.get( 'timeError' ), '0,000' ),
                    Ext.util.Format.number( storeItem.get( 'avgTimeError' ), '0,000.00' ),
                    Ext.util.Format.number( storeItem.get( 'countSuccessError' ), '0,000' ),
                    Ext.util.Format.number( storeItem.get( 'avgTimeSuccessError' ), '0,000.00' ) );

                this.update( html );
              }
            }
          }
        }
      ]
    } );

    me.callParent( [config] );
  }
} );



