/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.main.scheduler.quartz.stats.FastestExecutedJobsChart', {
  extend : 'Ext.chart.Chart',

  requires : [
    'QDesk.Msg',
    'QDesk.enums.ExecStatus',
    'QDesk.enums.scheduler.quartz.SchedulerStatisticsType',
    'QDesk.store.quartz.stats.ExecStatDataStore',
    'QDesk.util.EnumUtils',

    'Ext.chart.theme.QuartzFastestExecutedJobsChartTheme'
  ],

  style : 'background:#fff',

  animate : true,

  shadow : true,

  theme : 'QuartzFastestExecutedJobsChartTheme',

//  legend : {
//    position : 'right'
//  },

  qdesk : {
    /**
     * Required config parameter with the statistics period length for this chart.
     */
    periodLength : undefined,

    /**
     * Required config parameter with the statistics period start date for this chart.
     */
    periodStart : undefined
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.periodLength )
      Ext.Error.raise( 'Required config parameter missing: qdesk.periodLength' );

    if ( !config.qdesk.periodStart )
      Ext.Error.raise( 'Required config parameter missing: qdesk.periodStart' );

    Ext.apply( config, {
      store : Ext.create( 'QDesk.store.quartz.stats.ExecStatDataStore' ),

      axes : [
        {
          type : 'Numeric',
          minimum : 0,
          position : 'bottom',
          fields : ['avgTimeSuccessError'],
          title : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.FastestExecutedJobsChart.labelValueAxis' ),
          minorTickSteps : 1,
          grid : {
            odd : {
              opacity : 1,
              fill : '#ddd',
              stroke : '#bbb',
              'stroke-width' : 0.5
            }
          }
        },

        {
          type : 'Category',
          position : 'left',
          fields : ['jobDisplayName'],
          title : QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.FastestExecutedJobsChart.labelCategoryAxis' )
        }
      ],

      series : [
        {
          type : 'bar',
          axis : 'bottom',
          stacked : true,
          xField : 'jobDisplayName',
          yField : ['avgTimeSuccessError'],
          title : false,
          tips : {
            dismissDelay : 0,
            trackMouse : true,
            renderer : function ( storeItem, item )
            {
              var html = QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.FastestExecutedJobsChart.tooltipBar',
                  storeItem.get( 'jobGroupName' ),
                  storeItem.get( 'jobName' ),
                  Ext.util.Format.number( storeItem.get( 'countSuccess' ), '0,000' ),
                  Ext.util.Format.number( storeItem.get( 'timeSuccess' ), '0,000' ),
                  Ext.util.Format.number( storeItem.get( 'avgTimeSuccess' ), '0,000.00' ),
                  Ext.util.Format.number( storeItem.get( 'countError' ), '0,000' ),
                  Ext.util.Format.number( storeItem.get( 'timeError' ), '0,000' ),
                  Ext.util.Format.number( storeItem.get( 'avgTimeError' ), '0,000.00' ),
                  Ext.util.Format.number( storeItem.get( 'countVeto' ), '0,000' ),
                  Ext.util.Format.number( storeItem.get( 'avgTimeSuccessError' ), '0,000.00' ) );

              this.update( html );
            }
          }
        }
      ]
    } );

    me.callParent( [config] );
  }
} );