/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.main.scheduler.quartz.stats.SchedulerStatisticsTab', {
  extend : 'QDesk.view.base.scheduler.BaseSchedulerSubTab',

  requires : [
    'QDesk.Msg',
    'QDesk.util.license.LicensedProduct',
    'QDesk.util.license.LicensedProductFeatures',
    'QDesk.view.main.scheduler.common.WarningMessagePanel',
    'QDesk.view.main.scheduler.quartz.stats.SchedulerStatisticsPanel'
  ],

  alias : 'widget.QuartzSchedulerStatisticsTab',

  iconCls : 'quartzSchedulerStatisticsSubTabIcon',

  layout : {
    type : 'vbox',
    align : 'stretch'
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.connectionId )
      Ext.Error.raise( 'Required config parameter missing: qdesk.connectionId' );

    if ( !config.qdesk.jvmAgentInfo )
      Ext.Error.raise( 'Required config parameter missing: qdesk.jvmAgentInfo' );

    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    if ( licensedFeatures.SchedulerStatistics )
    {
      if ( config.qdesk.jvmAgentInfo.available )
      {
        Ext.apply( config, {
          layout : 'fit',
          items : [
            {
              xtype : 'QuartzSchedulerStatisticsPanel',
              itemId : 'statisticsPanel',
              qdesk : config.qdesk
            }
          ]
        } );
      }
      else
      {
        Ext.apply( config, {
          items : [
            {
              xtype : 'WarningMessagePanel',
              qdesk : {
                msg : QDesk.Msg.get( 'QDesk.featureAccessRestricted.jvmAgentNotAvailableMsg' )
              }
            }
          ]
        } );
      }
    }
    else
    {
      Ext.apply( config, {
        items : [
          {
            xtype : 'WarningMessagePanel',
            qdesk : {
              msg : QDesk.Msg.get( 'QDesk.featureAccessRestricted.notLicensedMsg',
                  QDesk.util.license.LicensedProduct.productName )
            }
          }
        ]
      } );
    }

    Ext.apply( config, {
      title : me._getTitle()
    } );

    me.callParent( [config] );
  },


  _getTitle : function ()
  {
    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    var title = QDesk.Msg.get( 'QDesk.view.main.scheduler.quartz.stats.SchedulerStatisticsTab.title' );
    if ( !licensedFeatures.SchedulerStatistics )
    {
      title = '<span class="notLicensed">' + title + '</span>'
    }

    return title;
  }
} );