/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.navigation.connections.ConnectionsTreePanel', {
  extend : 'Ext.tree.Panel',

  requires : [
    'Ext.data.StoreManager',
    'Ext.toolbar.Toolbar',
    'QDesk.Msg',
    'QDesk.store.ConnectionsTreeStore'
  ],

  alias : 'widget.ConnectionsTreePanel',

  cls : 'connectionsTreePanel',

  //autoScroll : true,

  viewConfig : {
    copy : false,

    plugins : {
      ptype : 'treeviewdragdrop',
      appendOnly : true,
      dragText : QDesk.Msg.get( 'QDesk.view.navigation.connections.ConnectionsTreePanel.dragText' )
    }
  },

  displayField : 'name',

  rootVisible : true,


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      root : {
        id : QDesk.util.constant.Const.CONNECTION_TREE_ROOT_ID,
        folderId : QDesk.util.constant.Const.CONNECTION_TREE_ROOT_FOLDER_ID,
        name : QDesk.Msg.get( 'QDesk.view.navigation.connections.ConnectionsTreePanel.rootNodeName' ),
        expanded : true,

        nodeType : 'folder'
      },

      dockedItems : [
        {
          xtype : 'toolbar',
          itemId : 'toolBar',
          dock : 'top',
          items : [
            {
              xtype : 'button',
              itemId : 'refreshButton',
              scale : 'small',
              iconCls : 'refresh',
              tooltip : QDesk.Msg.get( 'QDesk.view.navigation.connections.ConnectionsTreePanel.tooltipRefreshButton' ),
              disabled : true
            },
            {
              xtype : 'button',
              itemId : 'collapseButton',
              scale : 'small',
              iconCls : 'collapse',
              tooltip : QDesk.Msg.get( 'QDesk.view.navigation.connections.ConnectionsTreePanel.tooltipCollapseButton' ),
              disabled : true
            },
            '-',
            {
              xtype : 'button',
              itemId : 'addFolderOrConnectionButton',
              scale : 'small',
              iconCls : 'addFolderOrConnection',
              tooltip : QDesk.Msg.get( 'QDesk.view.navigation.connections.ConnectionsTreePanel.tooltipAddFolderOrConnectionButton' ),
              disabled : true,
              menu : [
                {
                  itemId : 'addFolderButton',
                  text : QDesk.Msg.get( 'QDesk.controller.navigation.ConnectionsTreePanel.addFolderButton' ),
                  iconCls : 'addFolder'
                },
                {
                  itemId : 'addConnectionButton',
                  text : QDesk.Msg.get( 'QDesk.controller.navigation.ConnectionsTreePanel.addConnectionButton' ),
                  iconCls : 'addConnection'
                }
              ]
            },
            {
              xtype : 'button',
              itemId : 'deleteFolderOrConnectionButton',
              scale : 'small',
              iconCls : 'deleteFolderOrConnection',
              // no tooltip, it is set dynamically based on the selection (folder / connection)
              disabled : true
            },
            {
              xtype : 'button',
              itemId : 'editFolderOrConnectionButton',
              scale : 'small',
              iconCls : 'editFolderOrConnection',
              // no tooltip, it is set dynamically based on the selection (folder / connection)
              disabled : true
            }
          ]
        }
      ]
    } );

    me.callParent( [config] );
  },


  initComponent : function ()
  {
    var me = this;

    // important to set the store before callParent as it expects the store!!!
    me.store = Ext.data.StoreManager.lookup( 'ConnectionsTreeStore' );

    me.callParent();
  }
} );
