/*
 * Copyright (c) 2011-2013 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm', {
  extend : 'QDesk.view.base.BaseFormPanel',

  requires : [
    'QDesk.Msg',
    'QDesk.enums.JmxProtocol',
    'QDesk.view.base.BaseFormPanel'
  ],

  alias : 'widget.EditSchedulerConnectionForm',

  fieldDefaults : {
    labelWidth : 60
  },

  qdesk : {
    /*
     * Mode of the form (see EditConnectionFolderFormMode).
     */
    mode : undefined,

    /*
     * Scheduler type (see QDesk.enums.scheduler.SchedulerType).
     */
    schedulerType : undefined
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.mode )
      Ext.Error.raise( 'Required config parameter missing: qdesk.mode' );

    if ( !config.qdesk.schedulerType )
      Ext.Error.raise( 'Required config parameter missing: qdesk.schedulerType' );

    // initially empty store used by the schedulerObjectName combo
    var schedulerObjectNameStore = Ext.create( 'Ext.data.Store', {
      fields : ['objectName'],
      data : []
    } );

    Ext.apply( config, {
      items : [
        {
          xtype : 'hiddenfield',
          name : 'id'
        },
        {
          xtype : 'textfield',
          itemId : 'name',
          name : 'name',
          fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelName' ),
          allowBlank : false
        },
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldsetLabelRemoteJmxService' ),
          layout : 'anchor',
          defaults : {
            anchor : '100%'
          },
          items : [
            {
              xtype : 'radiofield',
              itemId : 'serviceParamsRadio',
              boxLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.boxLabelServiceParams' )
            },
            {
              xtype : 'fieldcontainer',
              itemId : 'serviceParamsFields',
              padding : '0 0 0 10',
              layout : 'anchor',
              defaults : {
                anchor : '100%'
              },
              items : [
                {
                  xtype : 'combo',
                  itemId : 'protocol',
                  name : 'protocol',
                  fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelProtocol' ),
                  value : QDesk.enums.JmxProtocol.RMI,
                  allowBlank : false,
                  editable : false,
                  forceSelection : true,
                  queryMode : 'local',
                  store : 'enums.JmxProtocolStore',
                  valueField : 'value',
                  displayField : 'valueLabel'
                },
                {
                  xtype : 'textfield',
                  itemId : 'host',
                  name : 'host',
                  fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelHost' ),
                  allowBlank : false
                },
                {
                  xtype : 'numberfield',
                  itemId : 'port',
                  name : 'port',
                  fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelPort' ),
                  allowBlank : false,
                  minValue : 1,
                  maxValue : 65535
                }
              ]
            },


            {
              xtype : 'radiofield',
              itemId : 'serviceUrlRadio',
              boxLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.boxLabelServiceUrl' )
            },
            {
              xtype : 'fieldcontainer',
              itemId : 'serviceUrlFields',
              padding : '0 0 0 10',
              layout : 'anchor',
              defaults : {
                anchor : '100%'
              },
              items : [

                {
                  xtype : 'textfield',
                  itemId : 'serviceUrl',
                  name : 'serviceUrl',
                  fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelServiceUrl' ),
                  allowBlank : false
                }
              ]
            },


            {
              xtype : 'fieldset',
              collapsible : true,
              collapsed : true,
              title : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldsetLabelAuthentication' ),
              layout : 'anchor',
              defaults : {
                anchor : '100%'
              },
              items : [
                {
                  xtype : 'textfield',
                  itemId : 'username',
                  name : 'username',
                  fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelUsername' ),
                  allowBlank : true
                },
                {
                  xtype : 'textfield',
                  itemId : 'password',
                  name : 'password',
                  fieldLabel : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldLabelPassword' ),
                  inputType : 'password',
                  allowBlank : true
                }
              ]
            }
          ]
        },
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.fieldsetLabelSchedulerObjectName' ),
          layout : 'anchor',
          defaults : {
            anchor : '100%'
          },
          items : [
            {
              xtype : 'panel',
              border : false,
              layout : {
                type : 'hbox'
              },
              style : {
                marginBottom : '5px'
              },
              items : [
                {
                  xtype : 'combo',
                  itemId : 'schedulerObjectName',
                  name : 'schedulerObjectName',
                  allowBlank : false,
                  flex : 1,
                  queryMode : 'local',
                  store : schedulerObjectNameStore,
                  valueField : 'objectName',
                  displayField : 'objectName'
                },
                {
                  xtype : 'button',
                  itemId : 'discoverButton',
                  margin : '0 0 0 5',
                  text : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.buttonLabelDiscover' )
                }
              ]
            }
          ]
        },

        {
          xtype : 'panel',
          border : false,
          layout : {
            type : 'hbox',
            pack : 'end'
          },
          items : [
            {
              xtype : 'button',
              itemId : 'testButton',
              text : QDesk.Msg.get( 'QDesk.view.navigation.connections.EditSchedulerConnectionForm.buttonLabelTest' ),
              formBind : true
            }
          ]
        }
      ],

      buttons : [
        {
          itemId : 'cancelButton',
          text : QDesk.Msg.get( 'QDesk.buttonLabelCancel' )
        },
        {
          itemId : 'actionButton',
          text : me._getActionButtonText( config.qdesk.mode ),
          formBind : true
        }
      ]
    } );

    me.callParent( [config] );

    me.down( '#host' ).on( 'change', me._maybeEnableButtons, me );
    me.down( '#port' ).on( 'change', me._maybeEnableButtons, me );
    me.down( '#serviceUrl' ).on( 'change', me._maybeEnableButtons, me );
    me.down( '#schedulerObjectName' ).on( 'change', me._maybeEnableButtons, me );

    me.down( '#serviceParamsRadio' ).on( 'change', me._serviceModeChanged, me );
    me.down( '#serviceUrlRadio' ).on( 'change', me._serviceModeChanged, me );

    me.on( 'beforerender', me._beforeRender, me );
  },


  _serviceModeChanged : function ( radio, newValue, oldValue )
  {
    var me = this;
    if ( radio.itemId == 'serviceParamsRadio' && newValue )
    {
      me.down( '#serviceUrlRadio' ).setValue( false );
      me.down( '#serviceUrlFields' ).setDisabled( true );

      me.down( '#serviceParamsFields' ).setDisabled( false );
    }

    if ( radio.itemId == 'serviceUrlRadio' && newValue )
    {
      me.down( '#serviceParamsRadio' ).setValue( false );
      me.down( '#serviceParamsFields' ).setDisabled( true );

      me.down( '#serviceUrlFields' ).setDisabled( false );
    }

    me._maybeEnableButtons();
  },


  _getActionButtonText : function ( mode )
  {
    var me = this;

    switch ( mode )
    {
      case QDesk.view.navigation.connections.EditSchedulerConnectionFormMode.ADD:
        return QDesk.Msg.get( 'QDesk.buttonLabelAdd' );

      case QDesk.view.navigation.connections.EditSchedulerConnectionFormMode.EDIT:
        return QDesk.Msg.get( 'QDesk.buttonLabelUpdate' );

      default:
        Ext.Error.raise( "Unrecognized form mode: " + mode );
    }
  },


  _maybeEnableButtons : function ()
  {
    var me = this;

    var discoverButton = me.down( '#discoverButton' );
    var testButton = me.down( '#testButton' );

    var protocolField = me.down( '#host' );
    var hostField = me.down( '#host' );
    var portField = me.down( '#port' );

    var serviceUrlField = me.down( '#serviceUrl' );

    var schedulerObjectNameField = me.down( '#schedulerObjectName' );

    var serviceParamsRadio = me.down( '#serviceParamsRadio' );
    var serviceUrlRadio = me.down( '#serviceUrlRadio' );

    if ( serviceParamsRadio.getValue() )
    {
      discoverButton.setDisabled( !(hostField.isValid() && portField.isValid()) );
      testButton.setDisabled( !(hostField.isValid() && portField.isValid() && schedulerObjectNameField.isValid()) );
    }

    if ( serviceUrlRadio.getValue() )
    {
      discoverButton.setDisabled( !serviceUrlField.isValid() );
      testButton.setDisabled( !(serviceUrlField.isValid() && schedulerObjectNameField.isValid()) );
    }
  },


  _beforeRender : function ()
  {
    var me = this;
    var serviceUrl = me.getForm().findField( 'serviceUrl' ).getValue();

    if ( Ext.isEmpty( serviceUrl ) )
    {
      me.down( '#serviceParamsRadio' ).setValue( true );
      me.down( '#serviceParamsFields' ).setDisabled( false );

      me.down( '#serviceUrlRadio' ).setValue( false );
      me.down( '#serviceUrlFields' ).setDisabled( true );
    }
    else
    {
      me.down( '#serviceParamsRadio' ).setValue( false );
      me.down( '#serviceParamsFields' ).setDisabled( true );

      me.down( '#serviceUrlRadio' ).setValue( true );
      me.down( '#serviceUrlFields' ).setDisabled( false );
    }
  }


} );
